import turtle

pen = turtle.Turtle()
pen.speed(0)

#Creating Menu option buttons
def button(length):
    for i in range(4):
        pen.forward(length)
        pen.left(90)

def column(n, length):
    pen.left(270)
    for i in range(n):
        button(length)
        pen.forward(length)
    pen.penup()
    pen.left(90)
    pen.forward(n * length)
    pen.left(180)
    pen.pendown()

column(5, 100)

#Menu Options
pen.penup()
pen.goto(8, -46)
pen.write("START GAME!", font=("Arial",12,"normal"))

pen.penup()
pen.goto(6, -145)
pen.write("RULES", font=("Arial",12,"normal"))

pen.penup()
pen.goto(3, -248)
pen.write("HIGH SCORE", font=("Arial",12,"normal"))

pen.penup()
pen.goto(4, -343)
pen.write("FAQ", font=("Arial",12,"normal"))

pen.penup()
pen.goto(3, -450)
pen.write("QUIT GAME", font=("Arial",12,"normal"))

#Making options clickable
def btnclick(x,y):
    if x > 0 and x < 101 and y > 0 and y < -101:
        print("Start Game")
        print(x, y)
        turtle.clearscreen()
    elif x > 0 and x < 101 and y > 101 and y < -201:
        print("Rules")
        print(x, y)
        turtle.clearscreen()
    elif x > 0 and x < 101 and y > 201 and y < -301:
        print("Highscore")
        print(x, y)
        turtle.clearscreen()
    elif x > 0 and x < 101 and y > 301 and y < -401:
        print("Hi")
        print(x, y)
        turtle.clearscreen()
    elif x > 0 and x < 101 and y > 401 and y < -501:
        print("Hi")
        print(x, y)
        turtle.clearscreen()
    elif x > 0 and x < 101 and y > 501 and y < -601:
        print("Hi")
        print(x, y)
        turtle.clearscreen()
    else:
        print("Click One Of The Options!")
        print(x, y)
        btnclick(x, y)

turtle.onscreenclick(btnclick, 1)
turtle.listen()

turtle.done()




#words = ['apple', 'banana', 'doodke', 'test']

#print(' '.join(words))
word = []

def checkIfDone():

    f = "".join(word)

    if f == "banana":
        print(word)
        print("good job!")
    else:
        print(word)
        print("no...")

i = 0 
while i == 0:
    letter = input("The letter:\n")

    if letter == "cancel":
        i = 1
        break
    if letter == "done":
        checkIfDone()

    word.append(letter)

    print('The word right now is:' + ''.join(word))
    


from turtle import *
#from printTextMenu import *
from firebase import firebase


auth = firebase.FirebaseAuthentication('vs5o1lxVx5KvCdNc2BX0qpZfuJq4Ulnz3Q0Zs45f', 'schooldavid69420@gmail.com', extra={'id': 123})
firebase = firebase.FirebaseApplication('https://schoolproject-amen-default-rtdb.firebaseio.com', authentication=auth)


Menu = Screen()
Menu.screensize(500,500)

color = firebase.get('/Settings/backRoundColor', '')

Menu.bgcolor(f"{color}")

from printTextMenu import *

pensize(9)

def printMenu():

    up()
    goto(-50, 100)
    down()

    goto(100, 100)
    goto(100, 50)
    goto(-50, 50)
    goto(-50, 100)

    up()
    goto(-50, 0)
    down()

    goto(100, 0)
    goto(100, -50)
    goto(-50, -50)
    goto(-50, 0)

printMenu()



#pensize(9)
#
#up()
#goto(-245, 0)
#down()
#goto(238, 0)
#
#def checkPos(x, y):
#    print(f"X: {x}, Y: {y}")
#
#
#onscreenclick(checkPos)

mainloop()





from turtle import *


def checkPos(x,y):
    #print(f"X: {x}; Y: {y}")

    if x>=100 and x<150 and y<0 and y>-50:
        print(1)
    elif x>=100 and x<150 and y<-50 and y>-100:
        print(2)
    elif x>=100 and x<150 and y<-100 and y>-150:
        print(3)
    elif x>=150 and x<200 and y<0 and y>-50:
        print(4)
    elif x>=150 and x<200 and y<-50 and y>-100:
        print(5)
    elif x>=150 and x<200 and y<-100 and y>-150:
        print(6)
    elif x>=200 and x<250 and y<0 and y>-50:
        print(7)
    elif x>=200 and x<250 and y<-50 and y>-100:
        print(8)
    elif x>=200 and x<250 and y<-100 and y>-150:
        print(9)
    elif x>=250 and x<300 and y<0 and y>-50:
        print(10)
    elif x>=250 and x<300 and y<-50 and y>-100:
        print(11)
    elif x>=250 and x<300 and y<-100 and y>-150:
        print(12)
    elif x>=300 and x<350 and y<0 and y>-50:
        print(13)
    elif x>=300 and x<350 and y<-50 and y>-100:
        print(14)
    elif x>=300 and x<350 and y<-100 and y>-150:
        print(15)
    elif x>=350 and x<400 and y<0 and y>-50:
        print(16)
    elif x>=350 and x<400 and y<-50 and y>-100:
        print(17)
    elif x>=350 and x<400 and y<-100 and y>-150:
        print(18)
    elif x>=400 and x<450 and y<0 and y>-50:
        print(19)
    elif x>=400 and x<450 and y<-50 and y>-100:
        print(20)
    elif x>=400 and x<450 and y<-100 and y>-150:
        print(21)
    elif x>=450 and x<500 and y<0 and y>-50:
        print(22)
    elif x>=450 and x<500 and y<-50 and y>-100:
        print(23)
    elif x>=450 and x<500 and y<-100 and y>-150:
        print(24)
    elif x>=500 and x<550 and y<0 and y>-50:
        print(25)
    elif x>=500 and x<550 and y<-50 and y>-100:
        print(26)
    elif x>=500 and x<550 and y<-100 and y>-150:
        print(27)

    elif x>=600 and x<650 and y<-50 and y>-100:
        print(69)

    else:
        print('Error')




#checkPos2()

onscreenclick(checkPos)





from turtle import *


def checkPos(x,y):
    #print(f"X: {x}; Y: {y}")

    if x>=100 and x<150 and y<0 and y>-50:
        print(1)
    elif x>=100 and x<150 and y<-50 and y>-100:
        print(2)
    
    
    else:
        print('Error')




#checkPos2()

onscreenclick(checkPos)





from turtle import *

up()

def stRound():
    goto(517, -43)
    write("א", font=("Arial", 25, "normal"))

    goto(467, -43)
    write("ב", font=("Arial", 25, "normal"))

    goto(417, -43)
    write("ג", font=("Arial", 25, "normal"))

    goto(367, -43)
    write("ד", font=("Arial", 25, "normal"))

    goto(317, -43)
    write("ה", font=("Arial", 25, "normal"))

    goto(267, -43)
    write("ו", font=("Arial", 25, "normal"))

    goto(217, -43)
    write("ז", font=("Arial", 25, "normal"))

    goto(167, -43)
    write("ח", font=("Arial", 25, "normal"))

    goto(117, -43)
    write("ט", font=("Arial", 25, "normal"))

def ndRound():
    goto(523, -93)
    write("י", font=("Arial", 25, "normal"))

    goto(467, -93)
    write("כ", font=("Arial", 25, "normal"))

    goto(417, -93)
    write("ל", font=("Arial", 25, "normal"))

    goto(367, -93)
    write("מ", font=("Arial", 25, "normal"))

    goto(317, -93)
    write("נ", font=("Arial", 25, "normal"))

    goto(267, -93)
    write("ס", font=("Arial", 25, "normal"))

    goto(217, -93)
    write("ע", font=("Arial", 25, "normal"))

    goto(167, -93)
    write("פ", font=("Arial", 25, "normal"))

    goto(117, -93)
    write("צ", font=("Arial", 25, "normal"))

def rdRound():
    goto(517, -143)
    write("ק", font=("Arial", 25, "normal"))

    goto(467, -143)
    write("ר", font=("Arial", 25, "normal"))

    goto(417, -143)
    write("ש", font=("Arial", 25, "normal"))

    goto(367, -143)
    write("ת", font=("Arial", 25, "normal"))

    goto(317, -143)
    write("ך", font=("Arial", 25, "normal"))

    goto(267, -143)
    write("ם", font=("Arial", 25, "normal"))

    goto(217, -143)
    write("ן", font=("Arial", 25, "normal"))

    goto(167, -143)
    write("ף", font=("Arial", 25, "normal"))

    goto(117, -143)
    write("ץ", font=("Arial", 25, "normal"))

stRound()
ndRound()
rdRound()